@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = "3.01";
+our $VERSION = "3.02";
 
 use Exporter 'import';
 our @EXPORT_OK = qw(&vprintf &vsprintf);
@@ -16,7 +16,7 @@ sub vsprintf { &sprintf(@_) }
 sub sprintf {
     my($format, @args) = @_;
     my $uniqstr = _sub_uniqstr($format, @args)
-	or return CORE::sprintf($format, @args);
+	or return CORE::sprintf $format, @args;
     my @replace;
     for (@args) {
 	defined and /\P{ASCII}/ or next;
@@ -24,7 +24,7 @@ sub sprintf {
 	push @replace, [ $regex, $_, $len ];
 	$_ = $replace;
     }
-    local $_ = CORE::sprintf($format, @args);
+    local $_ = CORE::sprintf $format, @args;
     while (@replace) {
 	my($regex, $orig, $len) = @{shift @replace};
 	s/($regex)/_replace($1, $orig, $len)/e;
@@ -37,8 +37,6 @@ sub printf {
     $fh->print(&sprintf(@_));
 }
 
-use Text::VisualWidth::PP;
-
 sub _replace {
     my($matched, $orig, $len) = @_;
     if ((my $width = length $matched) == $len) {
@@ -51,31 +49,25 @@ sub _replace {
     }
 }
 
-sub _sub_uniqstr {
-    my $format = shift;
-    my @seq;
+use Text::VisualWidth::PP;
 
-  LOOP:
-    for my $i (1 .. 5) {
-	for my $j (1 .. 5) {
-	    next if $i == $j;
-	    my($c1, $c2) = map pack("C", $_), $i, $j;
-	    next if @seq and $seq[-1][1] eq $c1;
-	    push @seq, [$c1, $c2] if index($format, $c1.$c2) < 0;
-	    last LOOP if @seq >= @_;
+sub _sub_uniqstr {
+    local $_ = join '', @_;
+    my @pair;
+    for my $i (1 .. 255) {
+	my $c = pack "C", $i;
+	next if $c =~ /\s/ || /\Q$c/;
+	push @pair, $c;
+	if (@pair >= 2) {
+	    my($a, $b) = @pair;
+	    return sub {
+		my $len = Text::VisualWidth::PP::width +shift;
+		return undef if $len-- < 2;
+		[ $a . ($b x $len), qr/\Q${a}${b}\E*/, ++$len ];
+	    };
 	}
     }
-    return undef if @seq == 0;
-
-    my $n = 0;
-    sub {
-	my $len = Text::VisualWidth::PP::width +shift;
-	return undef if $len-- < 2;
-	my($c1, $c2) = @{$seq[$n++ % @seq]};
-	my $replace = $c1 . ($c2 x $len);
-	my $regex = qr/${c1}${c2}{1,$len}/;
-	[ $replace, $regex, ++$len ];
-    }
+    return undef;
 }
 
 1;
@@ -100,7 +92,7 @@ Text::VisualPrintf - printf family functions to handle Non-ASCII characters
 
 =head1 VERSION
 
-Version 3.01
+Version 3.02
 
 =head1 DESCRIPTION
 
@@ -109,7 +101,7 @@ capability of handling multi-byte wide characters properly.
 
 When the given string is truncated by the maximum precision, space
 character is padded if the wide character does not fit to the remained
-space.  It fails with the target width less than two.
+space.
 
 =head1 FUNCTIONS
 
@@ -136,19 +128,14 @@ to work with FILEHANDLE and printf.
 Strings in the LIST which contains wide-width character are replaced
 before formatting, and recovered after the process.
 
-Unique replacement string contains combinations of control characters
-(Control-A to Control-E).  If the FORMAT contains all of these two
-bytes combinations, the function behaves just like a standard one.
-
-Because this mechanism expects at least two bytes of string can be
-found in the formatted text, it does not work when the string is
-truncated to one.
+Unique replacement string contains combinations of two ASCII
+characters not found in the format string and all parameters.  If two
+characters are not available, function behaves just like a standard
+one.
 
 =head1 SEE ALSO
 
-L<Text::VisualPrintf::IO>
-
-L<Text::VisualWidth::PP>
+L<Text::VisualPrintf>, L<Text::VisualPrintf::IO>
 
 L<https://github.com/kaz-utashiro/Text-VisualPrintf>
 
